==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/OnClosedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnClosedEventArgsDescription } from "./OnClosedEventArgsDescription";
/**
 * @hidden
 */
var OnClosedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(OnClosedEventArgsDescriptionMetadata, _super);
    function OnClosedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OnClosedEventArgsDescriptionMetadata.b = function (a) {
        if (OnClosedEventArgsDescriptionMetadata.a == null) {
            OnClosedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OnClosedEventArgsDescriptionMetadata.c(OnClosedEventArgsDescriptionMetadata.a);
        }
        if (a.k(OnClosedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(OnClosedEventArgsDescriptionMetadata.a);
    };
    OnClosedEventArgsDescriptionMetadata.c = function (a) {
    };
    OnClosedEventArgsDescriptionMetadata.d = function (a) {
        OnClosedEventArgsDescriptionMetadata.b(a);
        a.ac("OnClosedEventArgs", function () { return new OnClosedEventArgsDescription(); });
        a.ab("OnClosedEventArgs", OnClosedEventArgsDescriptionMetadata.a);
    };
    OnClosedEventArgsDescriptionMetadata.$t = markType(OnClosedEventArgsDescriptionMetadata, 'OnClosedEventArgsDescriptionMetadata');
    OnClosedEventArgsDescriptionMetadata.a = null;
    return OnClosedEventArgsDescriptionMetadata;
}(Base));
export { OnClosedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/OnClosedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnClosedEventArgsDescription } from "./OnClosedEventArgsDescription";
/**
 * @hidden
 */
var OnClosedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(OnClosedEventArgsDescriptionMetadata, _super);
    function OnClosedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OnClosedEventArgsDescriptionMetadata.b = function (a) {
        if (OnClosedEventArgsDescriptionMetadata.a == null) {
            OnClosedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OnClosedEventArgsDescriptionMetadata.c(OnClosedEventArgsDescriptionMetadata.a);
        }
        if (a.k(OnClosedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(OnClosedEventArgsDescriptionMetadata.a);
    };
    OnClosedEventArgsDescriptionMetadata.c = function (a) {
    };
    OnClosedEventArgsDescriptionMetadata.d = function (a) {
        OnClosedEventArgsDescriptionMetadata.b(a);
        a.ae("OnClosedEventArgs", function () { return new OnClosedEventArgsDescription(); });
        a.ad("OnClosedEventArgs", OnClosedEventArgsDescriptionMetadata.a);
    };
    OnClosedEventArgsDescriptionMetadata.$t = markType(OnClosedEventArgsDescriptionMetadata, 'OnClosedEventArgsDescriptionMetadata');
    OnClosedEventArgsDescriptionMetadata.a = null;
    return OnClosedEventArgsDescriptionMetadata;
}(Base));
export { OnClosedEventArgsDescriptionMetadata };
